General Utils
=============

.. autofunction:: agilerl.utils.utils.make_vect_envs

.. autofunction:: agilerl.utils.utils.make_multi_agent_vect_envs

.. autofunction:: agilerl.utils.utils.make_skill_vect_envs

.. autofunction:: agilerl.utils.utils.observation_space_channels_to_first

.. autofunction:: agilerl.utils.utils.create_population

.. autofunction:: agilerl.utils.utils.save_population_checkpoint

.. autofunction:: agilerl.utils.utils.tournament_selection_and_mutation

.. autofunction:: agilerl.utils.utils.init_wandb

.. autofunction:: agilerl.utils.utils.calculate_vectorized_scores

.. autofunction:: agilerl.utils.utils.print_hyperparams

.. autofunction:: agilerl.utils.utils.plot_population_score

.. autofunction:: agilerl.utils.utils.get_env_defined_actions

.. autofunction:: agilerl.utils.utils.gather_tensor

.. autofunction:: agilerl.utils.utils.aggregate_metrics_across_gpus
